@@ -579,7 +579,7 @@ test_that("missing levels are handled correctly when using custom descriptive fu
     rgroup = c("randomisation", "week1", "week2", "week3"),
     n.rgroup = c(2, 2, 2, 2),
     htmlTable_args = structure(list(), .Names = character(0)),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   expected_missing_first <- structure(
     c("-", "-", "0.1 (&plusmn;0.5)", "0.2 (-0.2 - 0.5)",
@@ -596,7 +596,7 @@ test_that("missing levels are handled correctly when using custom descriptive fu
     rgroup = c("randomisation", "week1", "week2", "week3"),
     n.rgroup = c(2, 2, 2, 2),
     htmlTable_args = structure(list(), .Names = character(0)),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   expected_missing_second <- structure(
     c("0.1 (&plusmn;0.7)", "0.2 (-0.5 - 0.5)", "0.1 (&plusmn;0.5)",
@@ -614,7 +614,7 @@ test_that("missing levels are handled correctly when using custom descriptive fu
     rgroup = c("randomisation", "week1", "week2", "week3"),
     n.rgroup = c(2, 2, 2, 2),
     htmlTable_args = structure(list(), .Names = character(0)),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   expected_missing_both <- structure(
     c("0.1 (&plusmn;0.7)", "0.2 (-0.5 - 0.5)", "0.1 (&plusmn;0.5)",
@@ -631,7 +631,7 @@ test_that("missing levels are handled correctly when using custom descriptive fu
     rgroup = c("randomisation", "week1", "week2", "week3"),
     n.rgroup = c(2, 2, 2, 2),
     htmlTable_args = structure(list(), .Names = character(0)),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   expected_no_missing_2 <-  structure(
     c("0.2 (&plusmn;0.7)", "0.0 (-0.2 - 0.6)", "0.7 (&plusmn;0.5)",
@@ -652,7 +652,7 @@ test_that("missing levels are handled correctly when using custom descriptive fu
     rgroup = c("randomisation", "week1", "week2", "week3"),
     n.rgroup = c(2, 2, 2, 2),
     htmlTable_args = structure(list(), .Names = character(0)),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   expected_missing_first_2 <- structure(
     c("-", "-", "0.7 (&plusmn;0.5)", "0.4 (0.4 - 0.9)",
@@ -673,7 +673,7 @@ test_that("missing levels are handled correctly when using custom descriptive fu
     rgroup = c("randomisation", "week1", "week2", "week3"),
     n.rgroup = c(2, 2, 2, 2),
     htmlTable_args = structure(list(), .Names = character(0)),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   expected_missing_second_2 <- structure(
     c("0.2 (&plusmn;0.7)", "0.0 (-0.2 - 0.6)", "0.7 (&plusmn;0.5)",
@@ -694,7 +694,7 @@ test_that("missing levels are handled correctly when using custom descriptive fu
     rgroup = c("randomisation", "week1", "week2", "week3"),
     n.rgroup = c(2, 2, 2, 2),
     htmlTable_args = structure(list(), .Names = character(0)),
-    class = c("descMrg","matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   expected_missing_outer <- structure(
     c("-", "-", "0.7 (&plusmn;0.5)", "0.4 (0.4 - 0.9)",
@@ -714,7 +714,7 @@ test_that("missing levels are handled correctly when using custom descriptive fu
     rgroup = c("randomisation", "week1", "week2", "week3"),
     n.rgroup = c(2, 2, 2, 2),
     htmlTable_args = structure(list(), .Names = character(0)),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   expected_missing_all <- structure(
     c("0.2 (&plusmn;0.7)", "0.0 (-0.2 - 0.6)", "0.7 (&plusmn;0.5)",
@@ -732,7 +732,7 @@ test_that("missing levels are handled correctly when using custom descriptive fu
     rgroup = c("randomisation", "week1", "week2", "week3"),
     n.rgroup = c(2, 2, 2, 2),
     htmlTable_args = structure(list(), .Names = character(0)),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   out <- mergeDesc(lapply(levels(trial$visit), function(x)
     getDescriptionStatsBy(x = trial$outcome[trial$visit == x],
@@ -897,7 +897,7 @@ test_that("p-values are displayed in multi-row summaries when rgroup and n.rgrou
                                        .Names = "1")),
     n.rgroup = 2,
     htmlTable_args = structure(list(), .Names = character(0)),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   out <- mergeDesc(getDescriptionStatsBy(x = cars_missing$mpg,
                                          by = cars_missing$cyl,
@@ -918,7 +918,7 @@ test_that("p-vlues are displayed in multi-row summaries when rgroup and n.rgroup
                                        .Names = "1")),
     n.rgroup = 2L,
     htmlTable_args = structure(list(css.rgroup = ""), .Names = "css.rgroup"),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   out <- mergeDesc(getDescriptionStatsBy(x = cars_missing$mpg,
                                          by = cars_missing$cyl,
@@ -938,7 +938,7 @@ test_that("p-values are displayed in the rgroup title for both multi- and one-ro
                        add = list("&lt; 0.0001", "&lt; 0.0001")),
     n.rgroup = c(2, 1),
     htmlTable_args = structure(list(), .Names = character(0)),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   out <- mergeDesc(getDescriptionStatsBy(x = cars_missing$mpg,
                                          by = cars_missing$cyl,
@@ -964,7 +964,7 @@ test_that("p-values are displayed for both multi- and one-row summaries when rgr
                        add = structure(list(`1` = "&lt; 0.0001"), .Names = "1")),
     n.rgroup = c(2,1),
     htmlTable_args = structure(list(css.rgroup = ""), .Names = "css.rgroup"),
-    class = c("descMrg", "matrix"))
+    class = c("descMrg", class(matrix(1))))
 
   out <- mergeDesc(getDescriptionStatsBy(x = cars_missing$mpg,
                                          by = cars_missing$cyl,
